@@ -159,11 +159,37 @@ int MyConnect(dbh_t *sock, char* unixSocket, char* host, char* port,
 	}
 	return result;
 #elif defined(MYSQL_VERSION_ID)  &&  (MYSQL_VERSION_ID >= 32200)
+
 	mysql_init(*sock);
 #if defined(MYSQL_VERSION_ID)  &&  (MYSQL_VERSION_ID >= 32203)
-	if (imp_dbh  &&  imp_dbh->compression) {
-	    mysql_options(*sock, MYSQL_OPT_COMPRESS, NULL);
+	if (imp_dbh) {
+	    SV* sv = DBIc_IMP_DATA(imp_dbh);
+	    if (sv  &&  SvROK(sv)) {
+	        SV** svp;
+		HV* hv;
+		hv = (HV*) SvRV(sv);
+		if (SvTYPE(hv) == SVt_PVHV) {
+		    if ((svp = hv_fetch(hv, "mysql_compression", 17, FALSE))
+			&&  *svp  &&  SvTRUE(*svp)) {
+		        mysql_options(*sock, MYSQL_OPT_COMPRESS, NULL);
+		    }
+#if MYSQL_VERSION_ID >= 32210
+		    if ((svp = hv_fetch(hv, "mysql_read_default_group", 24,
+					FALSE))  &&
+			*svp  &&  SvTRUE(*svp)) {
+		        mysql_options(*sock, MYSQL_READ_DEFAULT_GROUP,
+				      SvPV(*svp, na));
+		    }
+		    if ((svp = hv_fetch(hv, "mysql_read_default_file", 23,
+					FALSE))  &&
+			*svp  &&  SvTRUE(*svp)) {
+		        mysql_options(*sock, MYSQL_READ_DEFAULT_FILE,
+				      SvPV(*svp, na));
+		    }
+		}
+	    }
 	}
+#endif /* MYSQL_VERSION_ID >= 32210 */
 #endif
 	return mysql_real_connect(*sock, host, user, password, dbname,
 				  portNr, unixSocket, 0) ?
@@ -267,12 +293,6 @@ static int _MyLogin(imp_dbh_t *imp_dbh) {
         dbname = NULL;
     }
 #ifdef DBD_MYSQL
-    if ((svp = hv_fetch(hv, "mysql_compression", 17, FALSE))  &&
-	*svp  &&  SvTRUE(*svp)) {
-        imp_dbh->compression = 1;
-    } else {
-        imp_dbh->compression = 0;
-    }
     if ((svp = hv_fetch(hv, "mysql_socket", 12, FALSE))  &&
 	*svp  &&  SvTRUE(*svp)) {
         unixSocket = SvPV(*svp, na);
@@ -1036,7 +1056,7 @@ AV* dbd_st_fetch(SV* sth, imp_sth_t* imp_sth) {
 	    STRLEN len = strlen(col);
 #endif
 	    if (ChopBlanks) {
-		while(len && isspace(col[len-1])) {
+		while(len && col[len-1] == ' ') {
 		    --len;
 		}
 	    }
